/*******************************************************************************
* File Name: LCDContrast.c
* Version 2.0
*
* Description:
*  This file provides the source code to the API for the LCDContrast
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "LCDContrast.h"

uint8 LCDContrast_initVar = 0u;


/*******************************************************************************
* Function Name: LCDContrast_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default LCDContrast configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (LCDContrast__QUAD == LCDContrast_CONFIG)
        LCDContrast_CONTROL_REG = LCDContrast_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        LCDContrast_TRIG_CONTROL1_REG  = LCDContrast_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        LCDContrast_SetInterruptMode(LCDContrast_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        LCDContrast_SetCounterMode(LCDContrast_COUNT_DOWN);
        LCDContrast_WritePeriod(LCDContrast_QUAD_PERIOD_INIT_VALUE);
        LCDContrast_WriteCounter(LCDContrast_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (LCDContrast__QUAD == LCDContrast_CONFIG) */

    #if (LCDContrast__TIMER == LCDContrast_CONFIG)
        LCDContrast_CONTROL_REG = LCDContrast_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        LCDContrast_TRIG_CONTROL1_REG  = LCDContrast_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        LCDContrast_SetInterruptMode(LCDContrast_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        LCDContrast_WritePeriod(LCDContrast_TC_PERIOD_VALUE );

        #if (LCDContrast__COMPARE == LCDContrast_TC_COMP_CAP_MODE)
            LCDContrast_WriteCompare(LCDContrast_TC_COMPARE_VALUE);

            #if (1u == LCDContrast_TC_COMPARE_SWAP)
                LCDContrast_SetCompareSwap(1u);
                LCDContrast_WriteCompareBuf(LCDContrast_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == LCDContrast_TC_COMPARE_SWAP) */
        #endif  /* (LCDContrast__COMPARE == LCDContrast_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (LCDContrast_CY_TCPWM_V2 && LCDContrast_TIMER_UPDOWN_CNT_USED && !LCDContrast_CY_TCPWM_4000)
            LCDContrast_WriteCounter(1u);
        #elif(LCDContrast__COUNT_DOWN == LCDContrast_TC_COUNTER_MODE)
            LCDContrast_WriteCounter(LCDContrast_TC_PERIOD_VALUE);
        #else
            LCDContrast_WriteCounter(0u);
        #endif /* (LCDContrast_CY_TCPWM_V2 && LCDContrast_TIMER_UPDOWN_CNT_USED && !LCDContrast_CY_TCPWM_4000) */
    #endif  /* (LCDContrast__TIMER == LCDContrast_CONFIG) */

    #if (LCDContrast__PWM_SEL == LCDContrast_CONFIG)
        LCDContrast_CONTROL_REG = LCDContrast_CTRL_PWM_BASE_CONFIG;

        #if (LCDContrast__PWM_PR == LCDContrast_PWM_MODE)
            LCDContrast_CONTROL_REG |= LCDContrast_CTRL_PWM_RUN_MODE;
            LCDContrast_WriteCounter(LCDContrast_PWM_PR_INIT_VALUE);
        #else
            LCDContrast_CONTROL_REG |= LCDContrast_CTRL_PWM_ALIGN | LCDContrast_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (LCDContrast_CY_TCPWM_V2 && LCDContrast_PWM_UPDOWN_CNT_USED && !LCDContrast_CY_TCPWM_4000)
                LCDContrast_WriteCounter(1u);
            #elif (LCDContrast__RIGHT == LCDContrast_PWM_ALIGN)
                LCDContrast_WriteCounter(LCDContrast_PWM_PERIOD_VALUE);
            #else 
                LCDContrast_WriteCounter(0u);
            #endif  /* (LCDContrast_CY_TCPWM_V2 && LCDContrast_PWM_UPDOWN_CNT_USED && !LCDContrast_CY_TCPWM_4000) */
        #endif  /* (LCDContrast__PWM_PR == LCDContrast_PWM_MODE) */

        #if (LCDContrast__PWM_DT == LCDContrast_PWM_MODE)
            LCDContrast_CONTROL_REG |= LCDContrast_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (LCDContrast__PWM_DT == LCDContrast_PWM_MODE) */

        #if (LCDContrast__PWM == LCDContrast_PWM_MODE)
            LCDContrast_CONTROL_REG |= LCDContrast_CTRL_PWM_PRESCALER;
        #endif  /* (LCDContrast__PWM == LCDContrast_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        LCDContrast_TRIG_CONTROL1_REG  = LCDContrast_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        LCDContrast_SetInterruptMode(LCDContrast_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (LCDContrast__PWM_PR == LCDContrast_PWM_MODE)
            LCDContrast_TRIG_CONTROL2_REG =
                    (LCDContrast_CC_MATCH_NO_CHANGE    |
                    LCDContrast_OVERLOW_NO_CHANGE      |
                    LCDContrast_UNDERFLOW_NO_CHANGE);
        #else
            #if (LCDContrast__LEFT == LCDContrast_PWM_ALIGN)
                LCDContrast_TRIG_CONTROL2_REG = LCDContrast_PWM_MODE_LEFT;
            #endif  /* ( LCDContrast_PWM_LEFT == LCDContrast_PWM_ALIGN) */

            #if (LCDContrast__RIGHT == LCDContrast_PWM_ALIGN)
                LCDContrast_TRIG_CONTROL2_REG = LCDContrast_PWM_MODE_RIGHT;
            #endif  /* ( LCDContrast_PWM_RIGHT == LCDContrast_PWM_ALIGN) */

            #if (LCDContrast__CENTER == LCDContrast_PWM_ALIGN)
                LCDContrast_TRIG_CONTROL2_REG = LCDContrast_PWM_MODE_CENTER;
            #endif  /* ( LCDContrast_PWM_CENTER == LCDContrast_PWM_ALIGN) */

            #if (LCDContrast__ASYMMETRIC == LCDContrast_PWM_ALIGN)
                LCDContrast_TRIG_CONTROL2_REG = LCDContrast_PWM_MODE_ASYM;
            #endif  /* (LCDContrast__ASYMMETRIC == LCDContrast_PWM_ALIGN) */
        #endif  /* (LCDContrast__PWM_PR == LCDContrast_PWM_MODE) */

        /* Set other values from customizer */
        LCDContrast_WritePeriod(LCDContrast_PWM_PERIOD_VALUE );
        LCDContrast_WriteCompare(LCDContrast_PWM_COMPARE_VALUE);

        #if (1u == LCDContrast_PWM_COMPARE_SWAP)
            LCDContrast_SetCompareSwap(1u);
            LCDContrast_WriteCompareBuf(LCDContrast_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == LCDContrast_PWM_COMPARE_SWAP) */

        #if (1u == LCDContrast_PWM_PERIOD_SWAP)
            LCDContrast_SetPeriodSwap(1u);
            LCDContrast_WritePeriodBuf(LCDContrast_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == LCDContrast_PWM_PERIOD_SWAP) */
    #endif  /* (LCDContrast__PWM_SEL == LCDContrast_CONFIG) */
    
}


/*******************************************************************************
* Function Name: LCDContrast_Enable
********************************************************************************
*
* Summary:
*  Enables the LCDContrast.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    LCDContrast_BLOCK_CONTROL_REG |= LCDContrast_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (LCDContrast__PWM_SEL == LCDContrast_CONFIG)
        #if (0u == LCDContrast_PWM_START_SIGNAL_PRESENT)
            LCDContrast_TriggerCommand(LCDContrast_MASK, LCDContrast_CMD_START);
        #endif /* (0u == LCDContrast_PWM_START_SIGNAL_PRESENT) */
    #endif /* (LCDContrast__PWM_SEL == LCDContrast_CONFIG) */

    #if (LCDContrast__TIMER == LCDContrast_CONFIG)
        #if (0u == LCDContrast_TC_START_SIGNAL_PRESENT)
            LCDContrast_TriggerCommand(LCDContrast_MASK, LCDContrast_CMD_START);
        #endif /* (0u == LCDContrast_TC_START_SIGNAL_PRESENT) */
    #endif /* (LCDContrast__TIMER == LCDContrast_CONFIG) */
}


/*******************************************************************************
* Function Name: LCDContrast_Start
********************************************************************************
*
* Summary:
*  Initializes the LCDContrast with default customizer
*  values when called the first time and enables the LCDContrast.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  LCDContrast_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time LCDContrast_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the LCDContrast_Start() routine.
*
*******************************************************************************/
void LCDContrast_Start(void)
{
    if (0u == LCDContrast_initVar)
    {
        LCDContrast_Init();
        LCDContrast_initVar = 1u;
    }

    LCDContrast_Enable();
}


/*******************************************************************************
* Function Name: LCDContrast_Stop
********************************************************************************
*
* Summary:
*  Disables the LCDContrast.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_BLOCK_CONTROL_REG &= (uint32)~LCDContrast_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the LCDContrast. This function is used when
*  configured as a generic LCDContrast and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the LCDContrast to operate in
*   Values:
*   - LCDContrast_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - LCDContrast_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - LCDContrast_MODE_QUAD - Quadrature decoder
*         - LCDContrast_MODE_PWM - PWM
*         - LCDContrast_MODE_PWM_DT - PWM with dead time
*         - LCDContrast_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_MODE_MASK;
    LCDContrast_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - LCDContrast_MODE_X1 - Counts on phi 1 rising
*         - LCDContrast_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - LCDContrast_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_QUAD_MODE_MASK;
    LCDContrast_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - LCDContrast_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - LCDContrast_PRESCALE_DIVBY2    - Divide by 2
*         - LCDContrast_PRESCALE_DIVBY4    - Divide by 4
*         - LCDContrast_PRESCALE_DIVBY8    - Divide by 8
*         - LCDContrast_PRESCALE_DIVBY16   - Divide by 16
*         - LCDContrast_PRESCALE_DIVBY32   - Divide by 32
*         - LCDContrast_PRESCALE_DIVBY64   - Divide by 64
*         - LCDContrast_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_PRESCALER_MASK;
    LCDContrast_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the LCDContrast runs
*  continuously or stops when terminal count is reached.  By default the
*  LCDContrast operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_ONESHOT_MASK;
    LCDContrast_CONTROL_REG |= ((uint32)((oneShotEnable & LCDContrast_1BIT_MASK) <<
                                                               LCDContrast_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPWMMode(uint32 modeMask)
{
    LCDContrast_TRIG_CONTROL2_REG = (modeMask & LCDContrast_6BIT_MASK);
}



/*******************************************************************************
* Function Name: LCDContrast_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_PWM_SYNC_KILL_MASK;
    LCDContrast_CONTROL_REG |= ((uint32)((syncKillEnable & LCDContrast_1BIT_MASK)  <<
                                               LCDContrast_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_PWM_STOP_KILL_MASK;
    LCDContrast_CONTROL_REG |= ((uint32)((stopOnKillEnable & LCDContrast_1BIT_MASK)  <<
                                                         LCDContrast_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_PRESCALER_MASK;
    LCDContrast_CONTROL_REG |= ((uint32)((deadTime & LCDContrast_8BIT_MASK) <<
                                                          LCDContrast_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - LCDContrast_INVERT_LINE   - Inverts the line output
*         - LCDContrast_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_INV_OUT_MASK;
    LCDContrast_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: LCDContrast_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_WriteCounter(uint32 count)
{
    LCDContrast_COUNTER_REG = (count & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 LCDContrast_ReadCounter(void)
{
    return (LCDContrast_COUNTER_REG & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - LCDContrast_COUNT_UP       - Counts up
*     - LCDContrast_COUNT_DOWN     - Counts down
*     - LCDContrast_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - LCDContrast_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_UPDOWN_MASK;
    LCDContrast_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_WritePeriod(uint32 period)
{
    LCDContrast_PERIOD_REG = (period & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 LCDContrast_ReadPeriod(void)
{
    return (LCDContrast_PERIOD_REG & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_RELOAD_CC_MASK;
    LCDContrast_CONTROL_REG |= (swapEnable & LCDContrast_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_WritePeriodBuf(uint32 periodBuf)
{
    LCDContrast_PERIOD_BUF_REG = (periodBuf & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 LCDContrast_ReadPeriodBuf(void)
{
    return (LCDContrast_PERIOD_BUF_REG & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_CONTROL_REG &= (uint32)~LCDContrast_RELOAD_PERIOD_MASK;
    LCDContrast_CONTROL_REG |= ((uint32)((swapEnable & LCDContrast_1BIT_MASK) <<
                                                            LCDContrast_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_WriteCompare(uint32 compare)
{
    #if (LCDContrast_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (LCDContrast_CY_TCPWM_4000) */

    #if (LCDContrast_CY_TCPWM_4000)
        currentMode = ((LCDContrast_CONTROL_REG & LCDContrast_UPDOWN_MASK) >> LCDContrast_UPDOWN_SHIFT);

        if (((uint32)LCDContrast__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)LCDContrast__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (LCDContrast_CY_TCPWM_4000) */
    
    LCDContrast_COMP_CAP_REG = (compare & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
*******************************************************************************/
uint32 LCDContrast_ReadCompare(void)
{
    #if (LCDContrast_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (LCDContrast_CY_TCPWM_4000) */

    #if (LCDContrast_CY_TCPWM_4000)
        currentMode = ((LCDContrast_CONTROL_REG & LCDContrast_UPDOWN_MASK) >> LCDContrast_UPDOWN_SHIFT);
        
        regVal = LCDContrast_COMP_CAP_REG;
        
        if (((uint32)LCDContrast__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)LCDContrast__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & LCDContrast_16BIT_MASK);
    #else
        return (LCDContrast_COMP_CAP_REG & LCDContrast_16BIT_MASK);
    #endif /* (LCDContrast_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: LCDContrast_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_WriteCompareBuf(uint32 compareBuf)
{
    #if (LCDContrast_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (LCDContrast_CY_TCPWM_4000) */

    #if (LCDContrast_CY_TCPWM_4000)
        currentMode = ((LCDContrast_CONTROL_REG & LCDContrast_UPDOWN_MASK) >> LCDContrast_UPDOWN_SHIFT);

        if (((uint32)LCDContrast__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)LCDContrast__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (LCDContrast_CY_TCPWM_4000) */
    
    LCDContrast_COMP_CAP_BUF_REG = (compareBuf & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
*******************************************************************************/
uint32 LCDContrast_ReadCompareBuf(void)
{
    #if (LCDContrast_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (LCDContrast_CY_TCPWM_4000) */

    #if (LCDContrast_CY_TCPWM_4000)
        currentMode = ((LCDContrast_CONTROL_REG & LCDContrast_UPDOWN_MASK) >> LCDContrast_UPDOWN_SHIFT);

        regVal = LCDContrast_COMP_CAP_BUF_REG;
        
        if (((uint32)LCDContrast__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)LCDContrast__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & LCDContrast_16BIT_MASK);
    #else
        return (LCDContrast_COMP_CAP_BUF_REG & LCDContrast_16BIT_MASK);
    #endif /* (LCDContrast_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: LCDContrast_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 LCDContrast_ReadCapture(void)
{
    return (LCDContrast_COMP_CAP_REG & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 LCDContrast_ReadCaptureBuf(void)
{
    return (LCDContrast_COMP_CAP_BUF_REG & LCDContrast_16BIT_MASK);
}


/*******************************************************************************
* Function Name: LCDContrast_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LCDContrast_TRIG_LEVEL     - Level
*     - LCDContrast_TRIG_RISING    - Rising edge
*     - LCDContrast_TRIG_FALLING   - Falling edge
*     - LCDContrast_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_TRIG_CONTROL1_REG &= (uint32)~LCDContrast_CAPTURE_MASK;
    LCDContrast_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LCDContrast_TRIG_LEVEL     - Level
*     - LCDContrast_TRIG_RISING    - Rising edge
*     - LCDContrast_TRIG_FALLING   - Falling edge
*     - LCDContrast_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_TRIG_CONTROL1_REG &= (uint32)~LCDContrast_RELOAD_MASK;
    LCDContrast_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LCDContrast_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LCDContrast_TRIG_LEVEL     - Level
*     - LCDContrast_TRIG_RISING    - Rising edge
*     - LCDContrast_TRIG_FALLING   - Falling edge
*     - LCDContrast_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_TRIG_CONTROL1_REG &= (uint32)~LCDContrast_START_MASK;
    LCDContrast_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LCDContrast_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LCDContrast_TRIG_LEVEL     - Level
*     - LCDContrast_TRIG_RISING    - Rising edge
*     - LCDContrast_TRIG_FALLING   - Falling edge
*     - LCDContrast_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_TRIG_CONTROL1_REG &= (uint32)~LCDContrast_STOP_MASK;
    LCDContrast_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LCDContrast_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - LCDContrast_TRIG_LEVEL     - Level
*     - LCDContrast_TRIG_RISING    - Rising edge
*     - LCDContrast_TRIG_FALLING   - Falling edge
*     - LCDContrast_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_TRIG_CONTROL1_REG &= (uint32)~LCDContrast_COUNT_MASK;
    LCDContrast_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << LCDContrast_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - LCDContrast_CMD_CAPTURE    - Trigger Capture command
*     - LCDContrast_CMD_RELOAD     - Trigger Reload command
*     - LCDContrast_CMD_STOP       - Trigger Stop command
*     - LCDContrast_CMD_START      - Trigger Start command
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    LCDContrast_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: LCDContrast_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the LCDContrast.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - LCDContrast_STATUS_DOWN    - Set if counting down
*     - LCDContrast_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 LCDContrast_ReadStatus(void)
{
    return ((LCDContrast_STATUS_REG >> LCDContrast_RUNNING_STATUS_SHIFT) |
            (LCDContrast_STATUS_REG & LCDContrast_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: LCDContrast_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - LCDContrast_INTR_MASK_TC       - Terminal count mask
*     - LCDContrast_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetInterruptMode(uint32 interruptMask)
{
    LCDContrast_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: LCDContrast_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - LCDContrast_INTR_MASK_TC       - Terminal count mask
*     - LCDContrast_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 LCDContrast_GetInterruptSourceMasked(void)
{
    return (LCDContrast_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: LCDContrast_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - LCDContrast_INTR_MASK_TC       - Terminal count mask
*     - LCDContrast_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 LCDContrast_GetInterruptSource(void)
{
    return (LCDContrast_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: LCDContrast_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - LCDContrast_INTR_MASK_TC       - Terminal count mask
*     - LCDContrast_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_ClearInterrupt(uint32 interruptMask)
{
    LCDContrast_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: LCDContrast_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - LCDContrast_INTR_MASK_TC       - Terminal count mask
*     - LCDContrast_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void LCDContrast_SetInterrupt(uint32 interruptMask)
{
    LCDContrast_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
